@@ -18,124 +18,131 @@ setMethod("$<-","genpop",function(x,name,value) {
 # '[' operator
 ###############
 ## genind
-setMethod("[", signature(x="genind", i="ANY", j="ANY", drop="ANY"), function(x, i, j, ..., loc=NULL, treatOther=TRUE, drop=FALSE) {
+setMethod("[", signature(x="genind", i="ANY", j="ANY", drop="ANY"), function(x, i, j, ..., loc=NULL, treatOther=TRUE, quiet=TRUE, drop=FALSE) {
 
-              if (missing(i)) i <- TRUE
-              if (missing(j)) j <- TRUE
+    if (missing(i)) i <- TRUE
+    if (missing(j)) j <- TRUE
 
-              pop <- NULL
-              if(is.null(x@pop)) { tab <- truenames(x) }
-              if(!is.null(x@pop)) {
-                  temp <- truenames(x)
-                  tab <- temp$tab
-                  pop <- temp$pop
-                  pop <- factor(pop[i])
-              }
+    pop <- NULL
+    if(is.null(x@pop)) { tab <- truenames(x) }
+    if(!is.null(x@pop)) {
+        temp <- truenames(x)
+        tab <- temp$tab
+        pop <- temp$pop
+        pop <- factor(pop[i])
+    }
 
-              ## handle loc argument
-              if(!is.null(loc)){
-                  loc <- as.character(loc)
-                  temp <- !loc %in% x@loc.fac
-                  if(any(temp)) { # si mauvais loci
-                      warning(paste("the following specified loci do not exist:", loc[temp]))
-                  }
-                  j <- x$loc.fac %in% loc
-              } # end loc argument
+    old.other <- other(x)
 
-              prevcall <- match.call()
+    ## handle loc argument
+    if(!is.null(loc)){
+        loc <- as.character(loc)
+        temp <- !loc %in% x@loc.fac
+        if(any(temp)) { # si mauvais loci
+            warning(paste("the following specified loci do not exist:", loc[temp]))
+        }
+        j <- x$loc.fac %in% loc
+    } # end loc argument
 
-              tab <- tab[i, j, ...,drop=FALSE]
+    prevcall <- match.call()
 
-              if(drop){
-                  allNb <- apply(tab, 2, sum, na.rm=TRUE) # allele absolute frequencies
-                  toKeep <- (allNb > 1e-10)
-                  tab <- tab[,toKeep, drop=FALSE]
-              }
+    tab <- tab[i, j, ...,drop=FALSE]
 
-              res <- genind(tab,pop=pop,prevcall=prevcall, ploidy=x@ploidy, type=x@type)
+    if(drop){
+        allNb <- apply(tab, 2, sum, na.rm=TRUE) # allele absolute frequencies
+        toKeep <- (allNb > 1e-10)
+        tab <- tab[,toKeep, drop=FALSE]
+    }
 
-              ## handle 'other' slot
-              nOther <- length(x@other)
-              namesOther <- names(x@other)
-              counter <- 0
-              if(treatOther){
-                  f1 <- function(obj,n=nrow(x@tab)){
-                      counter <<- counter+1
-                      if(!is.null(dim(obj)) && nrow(obj)==n) { # if the element is a matrix-like obj
-                          obj <- obj[i,,drop=FALSE]
-                      } else if(length(obj) == n) { # if the element is not a matrix but has a length == n
-                          obj <- obj[i]
-                          if(is.factor(obj)) {obj <- factor(obj)}
-                      } else {warning(paste("cannot treat the object",namesOther[counter]))}
+    res <- genind(tab,pop=pop,prevcall=prevcall, ploidy=x@ploidy, type=x@type)
 
-                      return(obj)
-                  } # end f1
+    ## handle 'other' slot
+    nOther <- length(x@other)
+    namesOther <- names(x@other)
+    counter <- 0
+    if(treatOther){
+        f1 <- function(obj,n=nrow(x@tab)){
+            counter <<- counter+1
+            if(!is.null(dim(obj)) && nrow(obj)==n) { # if the element is a matrix-like obj
+                obj <- obj[i,,drop=FALSE]
+            } else if(length(obj) == n) { # if the element is not a matrix but has a length == n
+                obj <- obj[i]
+                if(is.factor(obj)) {obj <- factor(obj)}
+            } else {if(!quiet) warning(paste("cannot treat the object",namesOther[counter]))}
 
-                  res@other <- lapply(x@other, f1) # treat all elements
+            return(obj)
+        } # end f1
 
-              } # end treatOther
+        res@other <- lapply(x@other, f1) # treat all elements
 
-              return(res)
-          })
+    } else {
+        other(res) <- old.other
+    } # end treatOther
+
+    return(res)
+})
 
 
 
 
 
 ## genpop
-setMethod("[", "genpop",
-          function(x, i, j, ..., loc=NULL, treatOther=TRUE, drop=FALSE) {
+setMethod("[", "genpop", function(x, i, j, ..., loc=NULL, treatOther=TRUE, drop=FALSE) {
 
-              if (missing(i)) i <- TRUE
-              if (missing(j)) j <- TRUE
+    if (missing(i)) i <- TRUE
+    if (missing(j)) j <- TRUE
 
-              tab <- truenames(x)
-
-              ## handle loc argument
-              if(!is.null(loc)){
-                  loc <- as.character(loc)
-                  temp <- !loc %in% x@loc.fac
-                  if(any(temp)) { # si mauvais loci
-                      warning(paste("the following specified loci do not exist:", loc[temp]))
-                  }
-                  j <- x$loc.fac %in% loc
-              } # end loc argument
-
-              prevcall <- match.call()
-              tab <- tab[i, j, ...,drop=FALSE]
-
-              if(drop){
-                  allNb <- apply(tab, 2, sum, na.rm=TRUE) # allele absolute frequencies
-                  toKeep <- (allNb > 1e-10)
-                  tab <- tab[,toKeep, drop=FALSE]
-              }
-
-              res <- genpop(tab,prevcall=prevcall)
-
-              ## handle 'other' slot
-              nOther <- length(x@other)
-              namesOther <- names(x@other)
-              counter <- 0
-              if(treatOther){
-                  f1 <- function(obj,n=nrow(x@tab)){
-                      counter <<- counter+1
-                      if(!is.null(dim(obj)) && nrow(obj)==n) { # if the element is a matrix-like obj
-                          obj <- obj[i,,drop=FALSE]
-                      } else if(length(obj) == n) { # if the element is not a matrix but has a length == n
-                          obj <- obj[i]
-                          if(is.factor(obj)) {obj <- factor(obj)}
-                      } else {warning(paste("cannot treat the object",namesOther[counter]))}
-
-                      return(obj)
-                  } # end f1
-
-                  res@other <- lapply(x@other, f1) # treat all elements
-
-              } # end treatOther
+    tab <- truenames(x)
+    old.other <- other(x)
 
 
-              return(res)
-          })
+    ## handle loc argument
+    if(!is.null(loc)){
+        loc <- as.character(loc)
+        temp <- !loc %in% x@loc.fac
+        if(any(temp)) { # si mauvais loci
+            warning(paste("the following specified loci do not exist:", loc[temp]))
+        }
+        j <- x$loc.fac %in% loc
+    } # end loc argument
+
+    prevcall <- match.call()
+    tab <- tab[i, j, ...,drop=FALSE]
+
+    if(drop){
+        allNb <- apply(tab, 2, sum, na.rm=TRUE) # allele absolute frequencies
+        toKeep <- (allNb > 1e-10)
+        tab <- tab[,toKeep, drop=FALSE]
+    }
+
+    res <- genpop(tab,prevcall=prevcall)
+
+    ## handle 'other' slot
+    nOther <- length(x@other)
+    namesOther <- names(x@other)
+    counter <- 0
+    if(treatOther){
+        f1 <- function(obj,n=nrow(x@tab)){
+            counter <<- counter+1
+            if(!is.null(dim(obj)) && nrow(obj)==n) { # if the element is a matrix-like obj
+                obj <- obj[i,,drop=FALSE]
+            } else if(length(obj) == n) { # if the element is not a matrix but has a length == n
+                obj <- obj[i]
+                if(is.factor(obj)) {obj <- factor(obj)}
+            } else {warning(paste("cannot treat the object",namesOther[counter]))}
+
+            return(obj)
+        } # end f1
+
+        res@other <- lapply(x@other, f1) # treat all elements
+
+    } else {
+        other(res) <- old.other
+    } # end treatOther
+
+
+    return(res)
+})
 
 
 
