@@ -727,7 +727,7 @@ read.snp <- function(file, quiet=FALSE, chunkSize=1000,
     if(!quiet) cat("\n Reading biallelic SNP data file into a genlight object... \n\n")
     if(multicore && !require(multicore)) stop("multicore package requested but not installed")
     if(multicore && is.null(n.cores)){
-        n.cores <- multicore:::detectCores()
+        n.cores <- parallel:::detectCores()
     }
 
     call <- match.call()
@@ -929,7 +929,7 @@ read.PLINK <- function(file, map.file=NULL, quiet=FALSE, chunkSize=1000,
     if(!quiet) cat("\n Reading PLINK raw format into a genlight object... \n\n")
     if(multicore && !require(multicore)) stop("multicore package requested but not installed")
     if(multicore && is.null(n.cores)){
-        n.cores <- multicore:::detectCores()
+        n.cores <- parallel:::detectCores()
     }
 
 
@@ -1043,7 +1043,7 @@ fasta2genlight <- function(file, quiet=FALSE, chunkSize=1000, saveNbAlleles=FALS
     if(!quiet) cat("\n Converting FASTA alignment into a genlight object... \n\n")
     if(multicore && !require(multicore)) stop("multicore package requested but not installed")
     if(multicore && is.null(n.cores)){
-        n.cores <- multicore:::detectCores()
+        n.cores <- parallel:::detectCores()
     }
 
 
